Be aware that the performance improvement from not splitting the string
so many times will only be realized in cases presenting more instances of
the splitting character than the minimal example here.
